@@ -8,6 +8,7 @@ use crate::rules::non_critical_lints::{
     no_console::NoConsoleConfig, no_empty_function::NoEmptyFunctionConfig,
     no_restricted_syntax::NoRestrictedSyntaxConfig, no_use_before_define::NoUseBeforeDefineConfig,
     prefer_regex_literals::PreferRegexLiteralsConfig, quotes::QuotesConfig, radix::RadixConfig,
+    yoda::YodaConfig,
 };
 
 #[derive(Debug, Clone, Copy, Serialize, Deserialize)]
@@ -133,4 +134,8 @@ pub struct LintConfig {
     #[cfg(feature = "non_critical_lints")]
     #[serde(default, alias = "defaultParamLast")]
     pub default_param_last: RuleConfig<()>,
+
+    #[cfg(feature = "non_critical_lints")]
+    #[serde(default)]
+    pub yoda: RuleConfig<YodaConfig>,
 }
